@@ -49,14 +49,105 @@
 //---------------------------------------------------------
 #include <wx/dcclient.h>
 #include <wx/clipbrd.h>
+#include <wx/display.h>
+#include <wx/frame.h>
+#include <wx/anidecod.h>
+#include <wx/imaggif.h>
+#include <wx/wfstream.h>
+#include <wx/quantize.h>
+#include <wx/filedlg.h>
 
 #include "3d_view.h"
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+class CSG_3DView_Twin : public wxFrame
+{
+public:
+
+	wxImage m_Image; CSG_3DView_Panel *m_pPanel { NULL };
+
+
+	//-----------------------------------------------------
+	CSG_3DView_Twin(wxWindow *pParent, CSG_3DView_Panel *pPanel)
+		: wxFrame(pParent, wxID_ANY, wxString::Format("%s | %s", _TL("Stereo View"), _TL("Right Eye")), wxDefaultPosition, wxDefaultSize, wxCAPTION|wxSTAY_ON_TOP)
+	{
+		m_pPanel = pPanel;
+
+		Sync_Position();
+
+		Show();
+	}
+
+
+	//-----------------------------------------------------
+	void	On_Paint		(wxPaintEvent &event)
+	{
+		if( m_Image.IsOk() && m_Image.GetWidth() > 0 && m_Image.GetHeight() > 0 )
+		{
+			wxPaintDC dc(this); dc.DrawBitmap(wxBitmap(m_Image), 0, 0, false);
+		}
+	}
+
+	//-----------------------------------------------------
+	bool	Sync_Size		(void)
+	{
+		wxSize Size(m_pPanel->GetClientSize());
+
+		SetClientSize(Size);
+
+		if( !m_Image.IsOk() || Size.x != m_Image.GetWidth() || Size.y != m_Image.GetHeight() )
+		{
+			if( !m_Image.Create(Size.x, Size.y) )
+			{
+				return( false );
+			}
+		}
+
+		return( true );
+	}
+
+	//-----------------------------------------------------
+	bool	Sync_Position	(void)
+	{
+		wxPoint Position = m_pPanel->GetScreenPosition();
+
+		if( wxDisplay::GetCount() > 1 && wxDisplay::GetFromPoint(Position) != wxNOT_FOUND )
+		{
+			int i = wxDisplay::GetFromPoint(Position); int j = (i + 1) % wxDisplay::GetCount();
+
+			wxRect ir(wxDisplay(i).GetGeometry()), jr(wxDisplay(j).GetGeometry());
+
+			wxPoint p(Position.x - ir.x + jr.x, Position.y - ir.y + jr.y);
+
+			SetPosition(p);
+
+			return( true );
+		}
+
+		return( false );
+	}
+
+	//-----------------------------------------------------
+	DECLARE_EVENT_TABLE()
+};
+
+//---------------------------------------------------------
+BEGIN_EVENT_TABLE(CSG_3DView_Twin, wxFrame)
+	EVT_PAINT      (CSG_3DView_Twin::On_Paint)
+END_EVENT_TABLE()
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -75,7 +166,7 @@ enum
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -95,7 +186,7 @@ END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -136,7 +227,7 @@ CSG_3DView_Panel::CSG_3DView_Panel(wxWindow *pParent, CSG_Grid *pDrape)
 
 	m_Parameters.Add_Color ("3D_VIEW" , "BGCOLOR"     , _TL("Background Color"     ), _TL(""), SG_COLOR_WHITE);
 
-	m_Parameters.Add_Bool  ("3D_VIEW" , "STEREO"      , _TL("Anaglyph"             ), _TL(""), m_bStereo);
+	m_Parameters.Add_Choice("3D_VIEW" , "STEREO"      , _TL("Stereo View"          ), _TL(""), CSG_String::Format("%s|%s|%s", _TL("off"), _TL("anaglyph"), _TL("twin window for right eye")));
 	m_Parameters.Add_Double("STEREO"  , "STEREO_DIST" , _TL("Eye Distance [Degree]"), _TL(""), m_dStereo, 0., true, 180., true);
 
 	//-----------------------------------------------------
@@ -156,12 +247,12 @@ CSG_3DView_Panel::CSG_3DView_Panel(wxWindow *pParent, CSG_Grid *pDrape)
 
 	//-----------------------------------------------------
 	m_Parameters.Add_Node("",
-		"PLAYER"	, _TL("Sequencer"),
+		"PLAYER"     , _TL("Sequencer"),
 		_TL("")
 	);
 
 	m_pPlay	= m_Parameters.Add_FixedTable("PLAYER",
-		"PLAY"		, _TL("Sequencer Positions"),
+		"PLAY"       , _TL("View Positions"),
 		_TL("")
 	)->asTable();
 
@@ -175,24 +266,58 @@ CSG_3DView_Panel::CSG_3DView_Panel(wxWindow *pParent, CSG_Grid *pDrape)
 	m_pPlay->Add_Field(_TL("Central Distance"), SG_DATATYPE_Double);
 	m_pPlay->Add_Field(_TL("Steps to Next"   ), SG_DATATYPE_Int   );
 
+	m_Parameters.Add_Bool("PLAYER",
+		"PLAY_FIRST" , _TL("Proceed to first View Position"),
+		_TL("If played once, the end of sequence will proceed to first view position. Also applies when frames will be stored to animated GIF file."),
+		true
+	);
+
 	m_Parameters.Add_FilePath("PLAYER",
-		"PLAY_FILE"	, _TL("Image File"),
+		"PLAY_FILE"  , _TL("Image File"),
 		_TL("file path, name and type used to save frames to image files"),
-		CSG_String::Format("%s (*.bmp)|*.bmp|%s (*.jpg, *.jif, *.jpeg)|*.jpg;*.jif;*.jpeg|%s (*.pcx)|*.pcx|%s (*.png)|*.png|%s (*.tif, *.tiff)|*.tif;*.tiff",
-			_TL("Windows or OS/2 Bitmap"),
-			_TL("JPEG - JFIF Compliant"),
-			_TL("Zsoft Paintbrush"),
-			_TL("Portable Network Graphics"),
-			_TL("Tagged Image File Format")
+		CSG_String::Format(
+			"%s (*.png)"                "|*.png|"
+			"%s (*.jpg, *.jif, *.jpeg)" "|*.jpg;*.jif;*.jpeg|"
+			"%s (*.tif, *.tiff)"        "|*.tif;*.tiff|"
+			"%s (*.gif)"                "|*.gif|"
+			"%s (*.bmp)"                "|*.bmp|"
+			"%s (*.pcx)"                "|*.pcx",
+			_TL("Portable Network Graphics"  ),
+			_TL("JPEG - JFIF Compliant"      ),
+			_TL("Tagged Image File Format"   ),
+			_TL("Graphics Interchange Format"),
+			_TL("Windows or OS/2 Bitmap"     ),
+			_TL("Zsoft Paintbrush"           )
 		), NULL, true
 	);
 
+	m_Parameters.Add_Int("PLAY_FILE",
+		"PLAY_DELAY" , _TL("Delay"),
+		_TL("Delay, in milliseconds, to wait between each frame. Used when storing animated GIF."),
+		100, 0, true
+	);
+
+	m_Parameters.Add_Int("PLAY_FILE",
+		"PLAY_COLORS", _TL("Color Depth"),
+		_TL("Number of color entries used when storing animated GIF."),
+		236, 2, true, 256, true
+	);
+
 	m_Play_State = SG_3DVIEW_PLAY_STOP;
 }
 
+//---------------------------------------------------------
+CSG_3DView_Panel::~CSG_3DView_Panel(void)
+{
+	if( m_pTwin )
+	{
+		delete(m_pTwin);
+	}
+}
+
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -214,7 +339,7 @@ bool CSG_3DView_Panel::Update_Parameters(bool bSave)
 		m_Parameters["CENTRAL_DIST"].Set_Value(m_Projector.Get_Central_Distance());
 
 		//-------------------------------------------------
-		m_Parameters["STEREO"      ].Set_Value(m_bStereo    );
+		m_Parameters["STEREO"      ].Set_Value(m_Stereo     );
 		m_Parameters["STEREO_DIST" ].Set_Value(m_dStereo    );
 
 		m_Parameters["BGCOLOR"     ].Set_Value(m_bgColor    );
@@ -254,7 +379,7 @@ bool CSG_3DView_Panel::Update_Parameters(bool bSave)
 		m_Projector.Set_Central_Distance(m_Parameters["CENTRAL_DIST"].asDouble());
 
 		//-------------------------------------------------
-		m_bStereo     = m_Parameters["STEREO"     ].asBool  ();
+		m_Stereo      = m_Parameters["STEREO"     ].asInt   ();
 		m_dStereo     = m_Parameters["STEREO_DIST"].asDouble();
 
 		m_bgColor     = m_Parameters["BGCOLOR"    ].asColor ();
@@ -323,11 +448,6 @@ int CSG_3DView_Panel::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Para
 		pParameters->Set_Enabled("MAP_DRAPE_MODE", pParameter->asBool());
 	}
 
-	if( pParameter->Cmp_Identifier("STEREO") )
-	{
-		pParameters->Set_Enabled("STEREO_DIST", pParameter->asBool());
-	}
-
 	if( pParameter->Cmp_Identifier("NORTH") )
 	{
 		pParameter->Set_Children_Enabled(pParameter->asBool());
@@ -338,9 +458,37 @@ int CSG_3DView_Panel::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Para
 		pParameter->Set_Children_Enabled(pParameter->asInt() != 2);
 	}
 
+	if( pParameter->Cmp_Identifier("STEREO") )
+	{
+		pParameters->Set_Enabled("STEREO_DIST", pParameter->asInt() != 0);
+	}
+
+	if( pParameter->Cmp_Identifier("PLAY_FILE") )
+	{
+		pParameters->Set_Enabled("PLAY_DELAY" , SG_File_Cmp_Extension(pParameter->asString(), "gif"));
+		pParameters->Set_Enabled("PLAY_COLORS", SG_File_Cmp_Extension(pParameter->asString(), "gif"));
+	}
+
 	return( 1 );
 }
 
+//---------------------------------------------------------
+bool CSG_3DView_Panel::Parameters_Dialog(void)
+{
+	Update_Parameters(true);
+
+	if( SG_UI_Dlg_Parameters(&m_Parameters, m_Parameters.Get_Name()) )
+	{
+		Update_Parameters(false);
+		Update_Parent();
+		Update_View(true);
+
+		return( true );
+	}
+
+	return( false );
+}
+
 //---------------------------------------------------------
 bool CSG_3DView_Panel::Parameter_Value_Toggle(const CSG_String &ID, bool bUpdate)
 {
@@ -411,7 +559,7 @@ bool CSG_3DView_Panel::Parameter_Value_Add(const CSG_String &ID, double Value, b
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -426,7 +574,7 @@ void CSG_3DView_Panel::Update_Parent(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -464,9 +612,13 @@ CSG_Table CSG_3DView_Panel::Get_Shortcuts(void)
 	ADD_SHORTCUT("7"        , _TL("Increase Perspective Distance for Central Projection"));
 	ADD_SHORTCUT("8"        , _TL("Decrease Perspective Distance for Central Projection"));
 
-	ADD_SHORTCUT("A"        , _TL("Anaglyph"));
-	ADD_SHORTCUT("9"        , _TL("Decrease Eye Distance Angle for Anaglyph View"));
-	ADD_SHORTCUT("0"        , _TL("Increase Eye Distance Angle for Anaglyph View"));
+	ADD_SHORTCUT("T"        , _TL("Toggle Stereo View Twin Window"));
+	ADD_SHORTCUT("U"        , _TL("Synchronize Stereo View Twin Window Position"));
+	ADD_SHORTCUT("A"        , _TL("Toggle Anaglyph View"));
+	ADD_SHORTCUT("9"        , _TL("Decrease Eye Distance Angle for Stereo View"));
+	ADD_SHORTCUT("0"        , _TL("Increase Eye Distance Angle for Stereo View"));
+
+	ADD_SHORTCUT("Shift+P"  , _TL("Properties"));
 
 	ADD_SHORTCUT("Ctrl+C"   , _TL("Copy to Clipboard"));
 
@@ -517,14 +669,25 @@ CSG_String CSG_3DView_Panel::Get_Usage(const CSG_Table &Shortcuts)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 void CSG_3DView_Panel::On_Key_Down(wxKeyEvent &event)
 {
 	//-----------------------------------------------------
-	if( event.ControlDown() )
+	if( event.ShiftDown() )
+	{
+		switch( event.GetKeyCode() )
+		{
+		default : event.Skip       (); return;
+
+		case 'P': Parameters_Dialog(); return;
+		}
+	}
+
+	//-----------------------------------------------------
+	else if( event.ControlDown() )
 	{
 		switch( event.GetKeyCode() )
 		{
@@ -579,11 +742,14 @@ void CSG_3DView_Panel::On_Key_Down(wxKeyEvent &event)
 		case '7'         : m_Projector.Inc_Central_Distance( 0.1); break;
 		case '8'         : m_Projector.Inc_Central_Distance(-0.1); break;
 
-		case 'A'         : m_bStereo  = !m_bStereo; break;
-		case '9'         : m_dStereo -= 0.5       ; break;
-		case '0'         : m_dStereo += 0.5       ; break;
+		case '9'         : m_dStereo -= 0.5; break;
+		case '0'         : m_dStereo += 0.5; break;
 
-		case 'B'         : m_bBox     = !m_bBox   ; break;
+		case 'A'         : Set_Stereo_Mode(m_Stereo != 1 ? 1 : 0); break;
+		case 'T'         : Set_Stereo_Mode(m_Stereo != 2 ? 2 : 0); break;
+		case 'U'         : if( m_pTwin ) { m_pTwin->Sync_Position(); } break;
+
+		case 'B'         : m_bBox     = !m_bBox           ; break;
 
 		case 'N'         : m_North    = (m_North  + 1) % 3; break;
 		case 'L'         : m_Labels   = (m_Labels + 1) % 3; break;
@@ -595,7 +761,7 @@ void CSG_3DView_Panel::On_Key_Down(wxKeyEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -726,7 +892,7 @@ void CSG_3DView_Panel::On_Mouse_Wheel(wxMouseEvent &event)
 
 		Update_View(); Update_Parent();
 
-		m_Mouse_Wheel_Accumulator -= event.GetWheelDelta();
+		m_Mouse_Wheel_Accumulator = 0;
 	}
 
 	if( m_Mouse_Wheel_Accumulator <= -event.GetWheelDelta() )
@@ -735,13 +901,13 @@ void CSG_3DView_Panel::On_Mouse_Wheel(wxMouseEvent &event)
 
 		Update_View(); Update_Parent();
 
-		m_Mouse_Wheel_Accumulator += event.GetWheelDelta();
+		m_Mouse_Wheel_Accumulator = 0;
 	}
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -757,7 +923,7 @@ bool CSG_3DView_Panel::On_Before_Draw(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -806,7 +972,14 @@ bool CSG_3DView_Panel::Update_View(bool bStatistics)
 		}
 	}
 
-	Set_Image(m_Image.GetData(), m_Image.GetWidth(), m_Image.GetHeight() );
+	Set_Image(m_Image);
+
+	Set_Stereo_Mode(m_Stereo);
+
+	if( m_pTwin && m_pTwin->Sync_Size() )
+	{
+		Set_Image_Twin(m_pTwin->m_Image);
+	}
 
 	//-----------------------------------------------------
 	CSG_Grid *pDrape = m_pDrape; if( m_pDrape && !m_Parameters("MAP_DRAPE")->asBool() ) m_pDrape = NULL;
@@ -814,6 +987,11 @@ bool CSG_3DView_Panel::Update_View(bool bStatistics)
 	if( Draw() )
 	{
 		Refresh(false); Update();
+
+		if( m_pTwin && m_pTwin->m_Image.IsOk() )
+		{
+			m_pTwin->Refresh(false); m_pTwin->Update();
+		}
 	}
 
 	m_pDrape = pDrape;
@@ -823,9 +1001,30 @@ bool CSG_3DView_Panel::Update_View(bool bStatistics)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_3DView_Panel::Set_Stereo_Mode(int Mode)
+{
+	if( Mode != 2 && m_pTwin != NULL )
+	{
+		delete(m_pTwin); m_pTwin = NULL;
+	}
+
+	if( Mode == 2 && m_pTwin == NULL )
+	{
+		m_pTwin = new CSG_3DView_Twin((wxWindow *)SG_UI_Get_Window_Main(), this);
+	}
+
+	m_Stereo = Mode;
+
+	return( true );
+}
+
+
+///////////////////////////////////////////////////////////
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -852,9 +1051,9 @@ bool CSG_3DView_Panel::Save_toClipboard(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -995,21 +1194,45 @@ bool CSG_3DView_Panel::_Play(void)
 	}
 
 	//-----------------------------------------------------
-	if( m_Play_State == SG_3DVIEW_PLAY_RUN_SAVE && *m_Parameters("PLAY_FILE")->asString() == '\0' )
+	CSG_String File;
+
+	if( m_Play_State == SG_3DVIEW_PLAY_RUN_SAVE )
 	{
-		SG_UI_Dlg_Error(_TL("invalid image file path"), _TL("3D View Sequencer"));
+		File = m_Parameters["PLAY_FILE"].asString();
 
-		m_Play_State = SG_3DVIEW_PLAY_STOP;
+		if( File.is_Empty() )
+		{
+			wxFileDialog dlg(GetParent(),
+				m_Parameters["PLAY_FILE"].Get_Name(), "", "",
+				m_Parameters["PLAY_FILE"].asFilePath()->Get_Filter(), wxFD_SAVE|wxFD_OVERWRITE_PROMPT
+			);
 
-		return( false );
+			if( dlg.ShowModal() == wxID_OK )
+			{
+				File = dlg.GetPath().wx_str();
+			}
+		}
+
+		if( File.is_Empty() )
+		{
+			SG_UI_Dlg_Error(_TL("invalid image file path"), _TL("3D View Sequencer"));
+
+			m_Play_State = SG_3DVIEW_PLAY_STOP;
+
+			return( false );
+		}
 	}
 
+	bool bAnimation = m_Play_State == SG_3DVIEW_PLAY_RUN_SAVE && SG_File_Cmp_Extension(File, "gif");
+
+	wxImageArray Images;
+
 	//-----------------------------------------------------
-	CSG_Matrix	Position(2, 9);
+	CSG_Matrix Position(2, 9);
 
 	PLAYER_READ(0);
 
-	int nPositions = (int)m_pPlay->Get_Count() + (m_Play_State == SG_3DVIEW_PLAY_RUN_LOOP ? 1 : 0);
+	int nPositions = (int)m_pPlay->Get_Count() + (m_Play_State == SG_3DVIEW_PLAY_RUN_LOOP || m_Parameters["PLAY_FIRST"].asBool() ? 1 : 0);
 
 	for(int iRecord=1, iFrame=0; iRecord<nPositions && m_Play_State!=SG_3DVIEW_PLAY_STOP; iRecord++)
 	{
@@ -1032,17 +1255,51 @@ bool CSG_3DView_Panel::_Play(void)
 
 			if( m_Play_State == SG_3DVIEW_PLAY_RUN_SAVE )
 			{
-				m_Image.SaveFile(SG_File_Make_Path(
-					SG_File_Get_Path     (m_Parameters("PLAY_FILE")->asString()),
-					SG_File_Get_Name     (m_Parameters("PLAY_FILE")->asString(), false) + CSG_String::Format(SG_T("%03d"), iFrame),
-					SG_File_Get_Extension(m_Parameters("PLAY_FILE")->asString())
-				).c_str());
+				if( bAnimation )
+				{
+					wxImage *pImage = new wxImage;
+
+					if( m_Image.HasAlpha() )
+					{
+						m_Image.ConvertAlphaToMask();
+					}
+
+					wxQuantize::Quantize(m_Image, *pImage, m_Parameters["PLAY_COLORS"].asInt());
+
+					Images.Add(pImage);
+				}
+				else
+				{
+					m_Image.SaveFile(SG_File_Make_Path(
+						SG_File_Get_Path     (File),
+						SG_File_Get_Name     (File, false) + CSG_String::Format("%03d", iFrame),
+						SG_File_Get_Extension(File)
+					).c_str());
+				}
 			}
 
 			SG_UI_Process_Get_Okay();
 		}
 	}
 
+	//-----------------------------------------------------
+	if( bAnimation && Images.Count() > 0 )
+	{
+		wxFileOutputStream Stream(File.c_str()); wxGIFHandler Handler;
+
+		SG_UI_Process_Set_Busy(true);
+
+		bool bResult = Stream.IsOk() && Handler.SaveAnimation(Images, &Stream, true, m_Parameters["PLAY_DELAY"].asInt());
+
+		SG_UI_Process_Set_Busy(false);
+
+		if( !bResult )
+		{
+			SG_UI_Dlg_Error(CSG_String::Format("%s\n\"%s\"", _TL("failed to create animation file!"), File.c_str()), _TL("3D View"));
+		}
+	}
+
+	//-----------------------------------------------------
 	if( m_Play_State != SG_3DVIEW_PLAY_RUN_LOOP )
 	{
 		m_Play_State = SG_3DVIEW_PLAY_STOP;
@@ -1055,9 +1312,9 @@ bool CSG_3DView_Panel::_Play(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
