@@ -52,9 +52,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -62,9 +62,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -146,9 +146,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -164,9 +164,9 @@ public:
 
 protected:
 
-	bool						m_bBox, m_bStereo;
+	bool						m_bBox;
 
-	int							m_bgColor, m_North, m_Labels, m_Label_Res;
+	int							m_bgColor, m_North, m_Labels, m_Label_Res, m_Label_zType, m_Stereo;
 
 	double						m_dStereo, m_BoxBuffer, m_North_Size, m_Label_Scale;
 
@@ -181,6 +181,7 @@ protected:
 
 	virtual bool				On_Before_Draw			(void)	{	return( true );	}
 	virtual bool				On_Draw					(void)	= 0;
+	virtual bool				On_After_Draw			(void)	{	return( true );	}
 
 	virtual int					Get_Color				(double Value);
 	virtual int					Dim_Color				(int Color, double Dim);
@@ -188,7 +189,8 @@ protected:
 	double						Get_Dim					(double x0, double y0, double z0, double x1, double y1, double z1, double x2, double y2, double z2, const CSG_Vector &LightSource, int Shading, double zScale = 1000.);
 	double						Get_Dim					(const CSG_Point_3D &p0, const CSG_Point_3D &p1, const CSG_Point_3D &p2, const CSG_Vector &LightSource, int Shading, double zScale = 1000.);
 
-	void						Set_Image				(BYTE *pRGB, int NX, int NY);
+	bool						Set_Image				(class wxImage &Image);
+	bool						Set_Image_Twin			(class wxImage &Image);
 	bool						Set_Drape				(CSG_Grid *pDrape);
 
 	void						Draw_Point				(int x, int y, double z, int Color, int Size);
@@ -219,7 +221,7 @@ private:
 
 	int							m_Image_NX, m_Image_NY, m_Color_Mode;
 
-	BYTE						*m_Image_pRGB;
+	BYTE						*m_Image_pRGB { NULL }, *m_Image_pTwin { NULL };
 
 	CSG_Matrix					m_Image_zMax;
 
@@ -233,9 +235,9 @@ private:
 	void						_Draw_North				(void);
 
 	void						_Draw_Labels			(int Front);
-	void						_Draw_Labels			(double Min, double Max,         const TSG_Point_3D &P, double Rx, double Ry, double Rz                             , int Resolution = 100, double Scale = 1.);
+	void						_Draw_Labels			(double Min, double Max,          const TSG_Point_3D &P, double Rx, double Ry, double Rz                             , int Resolution = 100, double Scale = 1.);
 	void						_Draw_Labels			(int Axis, const TSG_Point_3D &A, const TSG_Point_3D &B, double Rx, double Ry, double Rz, int Align = LABEL_ALIGN_TOP, int Resolution = 100, double Scale = 1.);
-	void						_Draw_Label				(const CSG_String &Text,         const TSG_Point_3D &P, double Rx, double Ry, double Rz, int Align = LABEL_ALIGN_TOP, int Resolution = 100, double Scale = 1.);
+	void						_Draw_Label				(const CSG_String &Text,          const TSG_Point_3D &P, double Rx, double Ry, double Rz, int Align = LABEL_ALIGN_TOP, int Resolution = 100, double Scale = 1.);
 
 	void						_Draw_Image				(class wxImage &Image, const CSG_Vector &Move, const CSG_Matrix &Rotate, int BGColor = -1, int xOffset = 0, int yOffset = 0);
 
@@ -248,9 +250,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
