@@ -596,7 +596,7 @@ bool CWKSP_Map_Layer::_Projected_Shapes_Clipped(const CSG_Rect &rMap, CSG_Shapes
 }
 
 //---------------------------------------------------------
-bool CWKSP_Map_Layer::_Projected_Shapes_Draw(CWKSP_Map_DC &dc_Map, int Flags, CSG_Shapes *pShapes, bool bSelection)
+bool CWKSP_Map_Layer::_Projected_Shapes_Draw(CSG_Map_DC &dc_Map, int Flags, CSG_Shapes *pShapes, bool bSelection)
 {
 	CSG_Shapes	Shapes;
 
@@ -606,7 +606,7 @@ bool CWKSP_Map_Layer::_Projected_Shapes_Draw(CWKSP_Map_DC &dc_Map, int Flags, CS
 	}
 	else
 	{
-		CSG_Rect	rMap(dc_Map.m_rWorld);	rMap.Inflate(dc_Map.m_DC2World, false);	// inflate by one pixel
+		CSG_Rect	rMap(dc_Map.rWorld());	rMap.Inflate(dc_Map.DC2World(), false);	// inflate by one pixel
 
 		_Projected_Shapes_Clipped(rMap, pShapes, Shapes);
 	}
@@ -625,13 +625,13 @@ bool CWKSP_Map_Layer::_Projected_Shapes_Draw(CWKSP_Map_DC &dc_Map, int Flags, CS
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CWKSP_Map_Layer::Draw(CWKSP_Map_DC &dc_Map, int Flags)
+bool CWKSP_Map_Layer::Draw(CSG_Map_DC &dc_Map, int Flags)
 {
 	CSG_Projection	prj_Layer, prj_Map;
 
 	if( !m_bProject || !_Projected_Get_Projections(prj_Layer, prj_Map) )
 	{
-		if( m_pLayer->do_Show(dc_Map.m_rWorld) )
+		if( m_pLayer->do_Show(dc_Map.rWorld()) )
 		{
 			m_pLayer->Draw(dc_Map, Flags);
 		}
@@ -640,7 +640,7 @@ bool CWKSP_Map_Layer::Draw(CWKSP_Map_DC &dc_Map, int Flags)
 	}
 
 	//-----------------------------------------------------
-	CSG_Rect	rLayer(_Projected_Get_Layer_Extent(dc_Map.m_rWorld));
+	CSG_Rect	rLayer(_Projected_Get_Layer_Extent(dc_Map.rWorld()));
 
 	if( !m_pLayer->do_Show(rLayer, false) )
 	{
@@ -699,7 +699,7 @@ bool CWKSP_Map_Layer::Draw(CWKSP_Map_DC &dc_Map, int Flags)
 			return( true );
 		}
 
-		CSG_Grid_System	System(dc_Map.m_DC2World, dc_Map.m_rWorld.Get_XMin(), dc_Map.m_rWorld.Get_YMin(), dc_Map.dc.GetSize().GetWidth(), dc_Map.dc.GetSize().GetHeight());
+		CSG_Grid_System	System(dc_Map.DC2World(), dc_Map.rWorld().Get_XMin(), dc_Map.rWorld().Get_YMin(), dc_Map.Get_DC().GetSize().GetWidth(), dc_Map.Get_DC().GetSize().GetHeight());
 
 		if( !System.is_Valid() || !Grid.Create(System, pGrid->Get_Type()) )
 		{
@@ -712,7 +712,7 @@ bool CWKSP_Map_Layer::Draw(CWKSP_Map_DC &dc_Map, int Flags)
 		CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 4);	// Coordinate Transformation (Grid)
 
 		if( pTool && pTool->Set_Manager(NULL)
-			&&  pTool->Set_Parameter("CRS_PROJ4"        , prj_Map.Get_Proj4())
+			&&  pTool->Set_Parameter("CRS_STRING"       , prj_Map.Get_WKT())
 			&&  pTool->Set_Parameter("RESAMPLING"       , m_pLayer->Get_Parameter("DISPLAY_RESAMPLING")->asInt() ? 3 : 0)
 			&&  pTool->Set_Parameter("DATA_TYPE"        , true)
 			&&  pTool->Set_Parameter("TARGET_AREA"      , m_bProject_Area)
@@ -739,7 +739,7 @@ bool CWKSP_Map_Layer::Draw(CWKSP_Map_DC &dc_Map, int Flags)
 			return( true );
 		}
 
-		CSG_Grid_System	System(dc_Map.m_DC2World, dc_Map.m_rWorld.Get_XMin(), dc_Map.m_rWorld.Get_YMin(), dc_Map.dc.GetSize().GetWidth(), dc_Map.dc.GetSize().GetHeight());
+		CSG_Grid_System	System(dc_Map.DC2World(), dc_Map.rWorld().Get_XMin(), dc_Map.rWorld().Get_YMin(), dc_Map.Get_DC().GetSize().GetWidth(), dc_Map.Get_DC().GetSize().GetHeight());
 
 		if( !System.is_Valid() )
 		{
@@ -752,7 +752,7 @@ bool CWKSP_Map_Layer::Draw(CWKSP_Map_DC &dc_Map, int Flags)
 		CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 3);	// Coordinate Transformation (Grid List)
 
 		if( pTool && pTool->Set_Manager(NULL)
-			&&  pTool->Set_Parameter("CRS_PROJ4"        , prj_Map.Get_Proj4())
+			&&  pTool->Set_Parameter("CRS_STRING"       , prj_Map.Get_WKT())
 			&&  pTool->Set_Parameter("RESAMPLING"       , m_pLayer->Get_Parameter("DISPLAY_RESAMPLING")->asInt() ? 3 : 0)
 		//	&&  SG_TOOL_PARAMETER_SET("DATA_TYPE"       , 10) // "Preserve" => is already default!
 			&&  pTool->Set_Parameter("TARGET_AREA"      , true)
