@@ -207,19 +207,86 @@ CSG_String CSG_CRSProjector::Get_Description(void)
 {
 	CSG_String	s;
 
-	s	+= _TL("Projection routines make use of the Proj.4 Cartographic Projections library.");
+	s	+= _TL("Projection routines make use of the PROJ generic coordinate transformation software.");
 	s	+= "\n";
-	s	+= _TW("Proj.4 was originally developed by Gerald Evenden and later continued by the "
-		       "United States Department of the Interior, Geological Survey (USGS).");
+	s	+= _TL("PROJ Version is ") + Get_Version();
 	s	+= "\n";
-	s	+= _TL("Proj.4 Version is ") + Get_Version();
-	s	+= "\n";
-	s	+= "<a target=\"_blank\" href=\"https://proj.org\">Proj.4 Homepage</a>";
+	s	+= "<a target=\"_blank\" href=\"https://proj.org\">PROJ Homepage</a>";
 
 	return( s );
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_String CSG_CRSProjector::Convert_CRS_To_PROJ(const CSG_String &Definition)
+{
+	return( Convert_CRS_Format(Definition, TCRS_Format::PROJ) );
+}
+
+CSG_String CSG_CRSProjector::Convert_CRS_To_JSON(const CSG_String &Definition, bool bMultiLine)
+{
+	return( Convert_CRS_Format(Definition, TCRS_Format::JSON, bMultiLine) );
+}
+
+CSG_String CSG_CRSProjector::Convert_CRS_To_ESRI(const CSG_String &Definition)
+{
+	return( Convert_CRS_Format(Definition, TCRS_Format::ESRI) );
+}
+
+CSG_String CSG_CRSProjector::Convert_CRS_To_WKT1(const CSG_String &Definition, bool bMultiLine)
+{
+	return( Convert_CRS_Format(Definition, TCRS_Format::WKT1, bMultiLine) );
+}
+
+CSG_String CSG_CRSProjector::Convert_CRS_To_WKT2(const CSG_String &Definition, bool bMultiLine, bool bSimplified)
+{
+	return( Convert_CRS_Format(Definition, TCRS_Format::WKT2, bMultiLine, bSimplified) );
+}
+
+//---------------------------------------------------------
+CSG_String CSG_CRSProjector::Convert_CRS_Format(const CSG_String &Definition, TCRS_Format Format, bool bMultiLine, bool bSimplified)
+{
+	if( Definition.Find("+proj") >= 0 && Definition.Find("+type=crs") < 0 )
+	{
+		return( Convert_CRS_Format(Definition + " +type=crs", Format, bMultiLine) );
+	}
+
+	#if PROJ_VERSION_MAJOR >= 6
+	CSG_String CRS; PJ *pProjection = proj_create(0, Definition);
+
+	if( pProjection )
+	{
+		const char *s = NULL, *options[] = { bMultiLine ? "MULTILINE=YES" : "MULTILINE=NO", NULL };
+
+		switch( Format )
+		{
+		case TCRS_Format::PROJ   : s = proj_as_proj_string(0, pProjection, PJ_PROJ_STRING_TYPE::PJ_PROJ_5, 0); break;
+		case TCRS_Format::JSON   : s = proj_as_projjson(0, pProjection, options); break;
+		case TCRS_Format::ESRI   : s = proj_as_wkt(0, pProjection, PJ_WKT_TYPE::PJ_WKT1_ESRI, options); break;
+		case TCRS_Format::WKT1   : s = proj_as_wkt(0, pProjection, PJ_WKT_TYPE::PJ_WKT1_GDAL, options); break;
+		case TCRS_Format::WKT2   : s = proj_as_wkt(0, pProjection, bSimplified ? PJ_WKT_TYPE::PJ_WKT2_2015_SIMPLIFIED : PJ_WKT_TYPE::PJ_WKT2_2015, options); break;
+		case TCRS_Format::WKT2015: s = proj_as_wkt(0, pProjection, bSimplified ? PJ_WKT_TYPE::PJ_WKT2_2015_SIMPLIFIED : PJ_WKT_TYPE::PJ_WKT2_2015, options); break;
+		case TCRS_Format::WKT2018: s = proj_as_wkt(0, pProjection, bSimplified ? PJ_WKT_TYPE::PJ_WKT2_2018_SIMPLIFIED : PJ_WKT_TYPE::PJ_WKT2_2018, options); break;
+		case TCRS_Format::WKT2019: s = proj_as_wkt(0, pProjection, bSimplified ? PJ_WKT_TYPE::PJ_WKT2_2019_SIMPLIFIED : PJ_WKT_TYPE::PJ_WKT2_2019, options); break;
+		}
+
+		if( s && *s )
+		{
+			CRS = CSG_String::from_UTF8(s); CRS.Replace("\"unknown\"", "\"<custom>\"");
+		}
+
+		proj_destroy(pProjection);
+	}
+	#endif
+
+	return( CRS );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -229,18 +296,39 @@ bool CSG_CRSProjector::_Set_Projection(const CSG_Projection &Projection, void **
 {
 	PROJ4_FREE(*ppProjection);
 
+	CSG_String Proj4(Projection.Get_Proj4());
+
+	{
+		int i = Proj4.Find("+type");
+
+		if( i >= 0 )
+		{
+			CSG_String Right(Proj4.Right(Proj4.Length() - i).AfterFirst('='));
+
+			if( Right.BeforeFirst('+').Find("crs") >= 0 )
+			{
+				Proj4 = Proj4.Left(i);
+
+				if( (i = Right.Find('+')) >= 0 )
+				{
+					Proj4 += Right.Right(Right.Length() - i);
+				}
+			}
+		}
+	}
+
 	//-------------------------------------------------
 	#if PROJ_VERSION_MAJOR < 6
-	if( (*ppProjection = pj_init_plus(Projection.Get_Proj4())) == NULL )
+	if( (*ppProjection = pj_init_plus(Proj4)) == NULL )
 	{
-		CSG_String	Error(pj_strerrno(pj_errno));
+		CSG_String Error(pj_strerrno(pj_errno));
 	#else
-	if( (*ppProjection = proj_create((PJ_CONTEXT *)m_pContext, Projection.Get_Proj4())) == NULL )
+	if( (*ppProjection = proj_create((PJ_CONTEXT *)m_pContext, Proj4)) == NULL )
 	{
-		CSG_String	Error(proj_errno_string(proj_errno((PJ *)(*ppProjection))));
+		CSG_String Error(proj_errno_string(proj_errno((PJ *)(*ppProjection))));
 	#endif
 
-		SG_UI_Msg_Add_Error(CSG_String::Format("Proj4 [%s]: %s", _TL("initialization"), Error.c_str()));
+		SG_UI_Msg_Add_Error(CSG_String::Format("PROJ [%s]: %s", _TL("initialization"), Error.c_str()));
 
 		return( false );
 	}
@@ -252,7 +340,7 @@ bool CSG_CRSProjector::_Set_Projection(const CSG_Projection &Projection, void **
 	if( bInverse && !proj_pj_info((PJ *)(*ppProjection)).has_inverse )
 	#endif
 	{
-		SG_UI_Msg_Add_Error(CSG_String::Format("Proj4 [%s]: %s", _TL("initialization"), _TL("inverse transformation not available")));
+		SG_UI_Msg_Add_Error(CSG_String::Format("PROJ [%s]: %s", _TL("initialization"), _TL("inverse transformation not available")));
 
 		return( false );
 	}
@@ -300,7 +388,7 @@ bool CSG_CRSProjector::Set_Inverse(bool bOn)
 		return( true );
 	}
 
-	SG_UI_Msg_Add_Error(CSG_String::Format("Proj4 [%s]: %s", _TL("initialization"), _TL("inverse transformation not available")));
+	SG_UI_Msg_Add_Error(CSG_String::Format("PROJ [%s]: %s", _TL("initialization"), _TL("inverse transformation not available")));
 
 	return( false );
 }
