@@ -75,6 +75,7 @@ protected:
 
 	virtual bool				On_Before_Draw			(void);
 	virtual bool				On_Draw					(void);
+	virtual bool				On_After_Draw			(void);
 
 	virtual int					Get_Color				(double Value);
 
@@ -83,13 +84,13 @@ private:
 
 	bool						m_Color_bGrad;
 
-	double						m_Color_Min, m_Color_Scale, m_Radius;
+	double						m_Color_Min, m_Color_Scale, m_Scale;
 
 	CSG_Colors					m_Colors;
 
 	CSG_Grid					*m_pGrid, *m_pZ;
 
-	TSG_Point_Z					**m_pNodes;
+	TSG_Point_3D				**m_pNodes;
 
 
 	bool						Create_Nodes			(void);
@@ -129,75 +130,26 @@ C3D_Viewer_Globe_Grid_Panel::C3D_Viewer_Globe_Grid_Panel(wxWindow *pParent, CSG_
 	Create_Nodes();
 
 	//-----------------------------------------------------
-	m_Parameters("BGCOLOR")->Set_Value((int)SG_GET_RGB(192, 192, 192));
-	m_Parameters("BOX"    )->Set_Value(false);
-	m_Parameters("LABELS" )->Set_Value(2);
+	m_Parameters("BGCOLOR")->Set_Value(m_bgColor = (int)SG_GET_RGB(192, 192, 192));
+	m_Parameters("BOX"    )->Set_Value(m_bBox    = false);
+	m_Parameters("LABELS" )->Set_Value(m_Labels  = 2);
+	m_Parameters("NORTH"  )->Set_Value(m_North   = 0);
 
 	//-----------------------------------------------------
-	m_Parameters.Add_Double("NODE_GENERAL",
-		"RADIUS"		, _TL("Radius"),
-		_TL(""),
-		6371., 0., true
+	m_Parameters.Add_Double("GENERAL"    , "RADIUS"      , _TL("Radius"      ), _TL(""), 6371., 0., true);
+
+	m_Parameters.Add_Bool  ("GENERAL"    , "COLOR_ASRGB" , _TL("RGB Values"  ), _TL(""), false);
+	m_Parameters.Add_Colors("COLOR_ASRGB", "COLORS"      , _TL("Colors"      ), _TL(""));
+	m_Parameters.Add_Range ("COLOR_ASRGB", "COLORS_RANGE", _TL("Value Range" ), _TL(""));
+	m_Parameters.Add_Bool  ("COLOR_ASRGB", "COLORS_GRAD" , _TL("Graduated"   ), _TL(""), true);
+
+	m_Parameters.Add_Choice("GENERAL"    , "DRAW_MODE"   , _TL("Draw"        ), _TL(""),
+		CSG_String::Format("%s|%s|%s", _TL("Faces"), _TL("Edges"), _TL("Nodes")), 0
 	);
 
-	//-----------------------------------------------------
-	m_Parameters.Add_Node("",
-		"NODE_VIEW"		, _TL("Grid View Settings"),
-		_TL("")
-	);
-
-	m_Parameters.Add_Bool("NODE_VIEW",
-		"COLOR_ASRGB"	, _TL("RGB Values"),
-		_TL(""),
-		false
-	);
-
-	m_Parameters.Add_Colors("COLOR_ASRGB",
-		"COLORS"		, _TL("Colors"),
-		_TL("")
-	);
-
-	m_Parameters.Add_Range("COLOR_ASRGB",
-		"COLORS_RANGE"	, _TL("Value Range"),
-		_TL("")
-	);
-
-	m_Parameters.Add_Bool("COLOR_ASRGB",
-		"COLORS_GRAD"	, _TL("Graduated"),
-		_TL(""),
-		true
-	);
-
-	m_Parameters.Add_Choice("NODE_VIEW",
-		"DRAW_MODE"		, _TL("Draw"),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s",
-			_TL("Faces"),
-			_TL("Edges"),
-			_TL("Nodes")
-		)
-	);
-
-	m_Parameters.Add_Choice("NODE_VIEW",
-		"SHADING"		, _TL("Shading"),
-		_TL(""),
-		CSG_String::Format("%s|%s",
-			_TL("none"),
-			_TL("shading")
-		), 1
-	);
-
-	m_Parameters.Add_Double("SHADING",
-		"SHADE_DEC"		, _TL("Light Source Height"),
-		_TL(""),
-		0., -180., true, 180., true
-	);
-
-	m_Parameters.Add_Double("SHADING",
-		"SHADE_AZI"		, _TL("Light Source Direction"),
-		_TL(""),
-		0., -180., true, 180., true
-	);
+	m_Parameters.Add_Choice("GENERAL"    , "SHADING"     , _TL("Light Source"), _TL(""), CSG_String::Format("%s|%s", _TL("no"), _TL("yes")), 1);
+	m_Parameters.Add_Double("SHADING"    , "SHADE_DEC"   , _TL("Height"      ), _TL(""), 0., -180., true, 180., true);
+	m_Parameters.Add_Double("SHADING"    , "SHADE_AZI"   , _TL("Direction"   ), _TL(""), 0., -180., true, 180., true);
 
 	//-----------------------------------------------------
 	m_Parameters("COLORS_RANGE")->asRange()->Set_Range(
@@ -239,8 +191,7 @@ int C3D_Viewer_Globe_Grid_Panel::On_Parameters_Enable(CSG_Parameters *pParameter
 
 	if( pParameter->Cmp_Identifier("SHADING") )
 	{
-		pParameters->Set_Enabled("SHADE_DEC"   ,  pParameter->asBool());
-		pParameters->Set_Enabled("SHADE_AZI"   ,  pParameter->asBool());
+		pParameter->Set_Children_Enabled(pParameter->asInt() > 0);
 	}
 
 	return( CSG_3DView_Panel::On_Parameters_Enable(pParameters, pParameter) );
@@ -254,8 +205,8 @@ int C3D_Viewer_Globe_Grid_Panel::On_Parameters_Enable(CSG_Parameters *pParameter
 //---------------------------------------------------------
 bool C3D_Viewer_Globe_Grid_Panel::Create_Nodes(void)
 {
-	m_pNodes    = (TSG_Point_Z **)SG_Malloc(m_pGrid->Get_NY    () * sizeof(TSG_Point_Z *));
-	m_pNodes[0] = (TSG_Point_Z  *)SG_Malloc(m_pGrid->Get_NCells() * sizeof(TSG_Point_Z  ));
+	m_pNodes    = (TSG_Point_3D **)SG_Malloc(m_pGrid->Get_NY    () * sizeof(TSG_Point_3D *));
+	m_pNodes[0] = (TSG_Point_3D  *)SG_Malloc(m_pGrid->Get_NCells() * sizeof(TSG_Point_3D  ));
 
 	for(int y=0; y<m_pGrid->Get_NY(); y++)
 	{
@@ -273,8 +224,8 @@ bool C3D_Viewer_Globe_Grid_Panel::Create_Nodes(void)
 //---------------------------------------------------------
 void C3D_Viewer_Globe_Grid_Panel::Update_Statistics(void)
 {
-	double Radius = m_Parameters("RADIUS")->asDouble();
-	double zScale = m_pZ ? m_Parameters("Z_SCALE")->asDouble() : 0.;
+	double Radius = m_Parameters("RADIUS" )->asDouble();
+	double zScale = m_Parameters("Z_SCALE")->asDouble();
 
 	m_Data_Min.x = m_Data_Max.x = 0.;
 	m_Data_Min.y = m_Data_Max.y = 0.;
@@ -282,7 +233,7 @@ void C3D_Viewer_Globe_Grid_Panel::Update_Statistics(void)
 
 	for(int y=0; y<m_pGrid->Get_NY(); y++)
 	{
-		TSG_Point_Z *pNode = m_pNodes[y];
+		TSG_Point_3D *pNode = m_pNodes[y];
 
 		double wy = M_DEG_TO_RAD * (m_pGrid->Get_YMin() + y * m_pGrid->Get_Cellsize());
 		double wx = M_DEG_TO_RAD * (m_pGrid->Get_XMin());
@@ -322,17 +273,18 @@ void C3D_Viewer_Globe_Grid_Panel::Update_Parent(void)
 //---------------------------------------------------------
 void C3D_Viewer_Globe_Grid_Panel::On_Key_Down(wxKeyEvent &event)
 {
-	switch( event.GetKeyCode() )
+	if( !event.ControlDown() && (event.GetKeyCode() == WXK_F1 || event.GetKeyCode() == WXK_F2) )
 	{
-	default:
-		CSG_3DView_Panel::On_Key_Down(event);
-		return;
+		m_Projector.Inc_zScaling(event.GetKeyCode() == WXK_F1 ? -0.5 : 0.5);
 
-	case WXK_F1: m_Parameters("Z_SCALE")->Set_Value(m_Parameters("Z_SCALE")->asDouble() -  0.5); break;
-	case WXK_F2: m_Parameters("Z_SCALE")->Set_Value(m_Parameters("Z_SCALE")->asDouble() +  0.5); break;
+		m_Parameters.Set_Parameter("Z_SCALE", m_Projector.Get_zScaling());
+
+		Update_Statistics(); Update_View();
+
+		return;
 	}
 
-	Update_View(true);
+	CSG_3DView_Panel::On_Key_Down(event);
 }
 
 //---------------------------------------------------------
@@ -343,8 +295,10 @@ void C3D_Viewer_Globe_Grid_Panel::On_Mouse_Motion(wxMouseEvent &event)
 		#define GET_MOUSE_X_RELDIFF	((double)(m_Down_Screen.x - event.GetX()) / (double)GetClientSize().x)
 		#define GET_MOUSE_Y_RELDIFF	((double)(m_Down_Screen.y - event.GetY()) / (double)GetClientSize().y)
 
-		m_Parameters("Z_SCALE")->Set_Value(m_Down_Value.x + GET_MOUSE_X_RELDIFF * 100.);
-		m_Projector.Set_zShift            (m_Down_Value.y + GET_MOUSE_Y_RELDIFF);
+		m_Projector.Set_Central_Distance(m_Down_Value.x + GET_MOUSE_X_RELDIFF);
+
+		m_Projector.Set_zScaling  (           m_Down_Value.y + GET_MOUSE_Y_RELDIFF * 100.);
+		m_Parameters.Set_Parameter("Z_SCALE", m_Down_Value.y + GET_MOUSE_Y_RELDIFF * 100.);
 
 		Update_View(true);
 
@@ -381,11 +335,23 @@ int C3D_Viewer_Globe_Grid_Panel::Get_Color(double Value)
 //---------------------------------------------------------
 bool C3D_Viewer_Globe_Grid_Panel::On_Before_Draw(void)
 {
+	CSG_3DView_Panel::On_Before_Draw();
+
+	m_Scale = m_Projector.Get_zScaling();
+
 	m_Projector.Set_zScaling(1.);
 
 	return( true );
 }
 
+//---------------------------------------------------------
+bool C3D_Viewer_Globe_Grid_Panel::On_After_Draw(void)
+{
+	m_Projector.Set_zScaling(m_Scale);
+
+	return( true );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -396,7 +362,7 @@ inline bool C3D_Viewer_Globe_Grid_Panel::Get_Node(int x, int y, TSG_Triangle_Nod
 {
 	if( m_pGrid->is_InGrid(x, y) )
 	{
-		TSG_Point_Z p = m_pNodes[y][x]; m_Projector.Get_Projection(p);
+		TSG_Point_3D p = m_pNodes[y][x]; m_Projector.Get_Projection(p);
 
 		Node.x = p.x;
 		Node.y = p.y;
@@ -634,12 +600,14 @@ C3D_Viewer_Globe_Grid::C3D_Viewer_Globe_Grid(void)
 		"Supplied grids have to use geographic coordinates. "
 	));
 
+	Set_Description(Get_Description() + C3D_Viewer_Globe_Grid_Panel::Get_Usage());
+
 	//-----------------------------------------------------
 	Parameters.Add_Grid("", "GRID", _TL("Grid"     ), _TL(""), PARAMETER_INPUT);
 	Parameters.Add_Grid("", "Z"   , _TL("Elevation"), _TL(""), PARAMETER_INPUT_OPTIONAL);
 
 	Parameters.Add_Choice("",
-		"RESAMPLING", _TL("Resampling"),
+		"RESAMPLING"   , _TL("Resampling"),
 		_TL(""),
 		CSG_String::Format("%s|%s",
 			_TL("no"),
@@ -648,10 +616,21 @@ C3D_Viewer_Globe_Grid::C3D_Viewer_Globe_Grid(void)
 	);
 
 	Parameters.Add_Double("RESAMPLING",
-		"RESOLUTION", _TL("Resolution"),
+		"RESOLUTION"   , _TL("Resolution"),
 		CSG_String::Format("[%s]", _TL("Degree")),
 		0.25, 0.001, true
 	);
+
+	Parameters.Add_Choice("RESAMPLING",
+		"INTERPOLATION", _TL("Interpolation"),
+		_TL(""),
+		CSG_String::Format("%s|%s|%s|%s",
+			_TL("Nearest Neighbour"           ),
+			_TL("Bilinear Interpolation"      ),
+			_TL("Bicubic Spline Interpolation"),
+			_TL("B-Spline Interpolation"      )
+		), 3
+	);
 }
 
 
@@ -698,15 +677,25 @@ bool C3D_Viewer_Globe_Grid::On_Execute(void)
 	//-----------------------------------------------------
 	if( Parameters("RESAMPLING")->asInt() == 1 )
 	{
+		TSG_Grid_Resampling Resampling;
+
+		switch( Parameters("INTERPOLATION")->asInt() )
+		{
+		default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
+		case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
+		case  2: Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
+		case  3: Resampling = GRID_RESAMPLING_BSpline         ; break;
+		}
+
 		CSG_Grid_System System(Parameters("RESOLUTION")->asDouble(), Get_System().Get_Extent());
 
 		if( pGrid->Get_Cellsize() != System.Get_Cellsize() )
 		{
-			Grid.Create(System); Grid.Assign(pGrid); pGrid = &Grid;
+			Grid.Create(System); Grid.Assign(pGrid, Resampling); pGrid = &Grid;
 
 			if( pZ )
 			{
-				Z.Create(System); Z.Assign(pZ); pZ = &Z;
+				Z.Create(System); Z.Assign(pZ, Resampling); pZ = &Z;
 			}
 		}
 	}
